
#ifndef SCRIPTWRAPPER_H
#define SCRIPTWRAPPER_H

#ifdef QMLUI
  #include "scriptv4.h"
#else
  #include "script.h"
#endif

#endif
